/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:taastrap/taastrap.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// The Base complete card
class BaseComplete extends StatelessWidget{

  /// The children widget inside this column
  final Widget childWidget;

  /// The back button callBack function
  final Function() backButtonCallBack;

  /// The continue button callBack function
  final Function() continueButtonCallBack;

  final double percent;

  BaseComplete({Key? key,
    required this.childWidget,
    required this.backButtonCallBack,
    required this.continueButtonCallBack,
    required this.percent
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    return VerticalScroll(
      childComponent: Column(
        children: [
          Padding(
            padding: EdgeInsets.only(bottom: 5, left: 10, right: 10),
            child: LinearPercentIndicator(
              lineHeight: 10,
              padding: EdgeInsets.only(top: 10),
              percent: this.percent,
              progressColor: DesignColors.bluePrimary,
            ),
          ),
          Padding(
            padding: EdgeInsets.only(top: 5),
            child: CustomCard(
              childComponent: Column(
                children: [
                  Padding(
                    padding: EdgeInsets.symmetric(vertical: 50, horizontal: 40),
                    child: this.childWidget,
                  ),
                  Padding(
                    padding: EdgeInsets.symmetric(vertical: 10),
                    child: BottomButtons(
                      backButtonText: Utils.translatedText("backButton"),
                      continueButtonText: Utils.translatedText("continueButton"),
                      backButtonCallBackFunction: () => this.backButtonCallBack(),
                      continueButtonCallBackFunction: () => this.continueButtonCallBack(),
                    ),
                  )
                ],
              ),
            ),
          )
        ],
      ),
    );
  }


}