/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';


/// Edit interests screen state
class EditInterestsState extends ChangeNotifier{

  /// Want talk value string
  final TextEditingController wantTalkValue;

  /// Looking for other value string
  final TextEditingController lookingForValue;

  EditInterestsState({required this.wantTalkValue, required this.lookingForValue});
}


/// Edit interests component
class EditInterests extends StatelessWidget{

  /// CallBack function for back button
  final Function() backButtonCallBack;

  /// CallBack function for continue button
  final Function() continueButtonCallBack;

  final double percent;

  EditInterests({Key? key,
    required this.backButtonCallBack,
    required this.continueButtonCallBack,
    required this.percent
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    return Consumer<EditInterestsState>(
      builder: (builder, editInterestsStateProvider, child){
        return BaseComplete(
          percent: this.percent,
            childWidget: Column(
              children: [
                Padding(
                  padding: EdgeInsets.only(top: 20),
                  child: BaseText(
                    texts: [Utils.translatedText("interestedInTitle")],
                    baseTextsType: [BaseTextType.title],
                    textsColor: [DesignColors.pinkyPrimary],
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(top: 10, bottom: 10),
                  child: BaseText(
                    texts: [Utils.translatedText("interestedInSubtitle")],
                    baseTextsType: [BaseTextType.subTitle],
                    textsColor: [DesignColors.greyPrimary],
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(top: 10, bottom: 20),
                  child: InputTag(),
                ),
                Padding(
                  padding: EdgeInsets.only(top: 20, bottom: 5),
                  child: BaseText(
                    texts: [Utils.translatedText("wantTalkAboutTitle")],
                    baseTextsType: [BaseTextType.title],
                    textsColor: [DesignColors.pinkyPrimary],
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(bottom: 20, top: 5),
                  child: BaseInput(
                    inputType: InputType.inputArea,
                    maxLines: 5,
                    placeholderText: Utils.translatedText("wantTalkAboutPlaceholderInput"),
                    controller: editInterestsStateProvider.wantTalkValue,
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(top: 20, bottom: 5),
                  child: BaseText(
                    texts: [Utils.translatedText("lookingForTitle")],
                    baseTextsType: [BaseTextType.title],
                    textsColor: [DesignColors.pinkyPrimary],
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(bottom: 20, top: 5),
                  child: BaseInput(
                    inputType: InputType.inputArea,
                    maxLines: 5,
                    placeholderText: Utils.translatedText("lookingForPlaceholder"),
                    controller: editInterestsStateProvider.lookingForValue,
                  ),
                ),
              ],
            ),
            backButtonCallBack: () => this.backButtonCallBack(),
            continueButtonCallBack: () => this.continueButtonCallBack()
        );
      }
    );
  }



}