/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:provider/single_child_widget.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// The provider to handle the state inside this custom filters widget
class FiltersProvider extends ChangeNotifier{

  /// The dynamic filters list
  final List<NetworkFilterElement> filters;

  FiltersProvider({required this.filters});

  Map<String, NetworkFilterState> filtersStateMapping(){
    Map<String, NetworkFilterState> mapping = {};
    this.filters.forEach((element) {
      mapping[element.filterKeyName] = NetworkFilterState(value: "");
    });
    return mapping;
  }

  /// The value mapping
  Map<String, dynamic> mappingValues(BuildContext context){
   Map<String, dynamic> mappingValues = {};
   Map<String, NetworkFilterState> tmp = this.filtersStateMapping();
   tmp.forEach((key, value) {
     mappingValues[key] = value.value;
   });
   return mappingValues;
  }

  List<SingleChildWidget> multiProviders(){
    List<SingleChildWidget> providers = [];
    Map<String, NetworkFilterState> tmp = this.filtersStateMapping();
    tmp.forEach((key, value) {
      providers.add(
          ChangeNotifierProvider<NetworkFilterState>(
            create: (_) => value,
          )
      );
    });
    return providers;
  }


}

/// Custom component to create a collapse widget to show inside the custom filters
class FiltersPlan extends StatelessWidget{
  
  @override
  Widget build(BuildContext context) {
    return Consumer<FiltersProvider>(
      builder: (builder, provider, child){
        return CustomExpansionTile(
          title: BaseText(
            texts: [Utils.translatedText("chooseYourMatchTitle")],
            baseTextsType: [BaseTextType.title],
          ),
          children: [
            VerticalScroll(
                childComponent: MultiProvider(
                  providers: provider.multiProviders(),
                  child: Column(
                    children: [
                      for(int i = 0; i < provider.filters.length; i++) Padding(
                        padding: EdgeInsets.symmetric(horizontal: 5, vertical: 15),
                        child: LineSettings(
                            title: Utils.translatedText(provider.filters[i].networkTitle),
                            subTitle: Utils.translatedText(provider.filters[i].networkSubTitle),
                            rightElement: Consumer<NetworkFilterState>(
                                builder: (builder, providerNetwork, child){
                                  return NetworkFilter(
                                    currentValue: providerNetwork.value,
                                    networkFilter: provider.filters[i],
                                  );
                                }
                            )
                        ),
                      )
                    ],
                  ),
                )
            )
          ],
        );
      }
    );
  }
  
  
  
  
}